package example

class AppConfigInfoController {

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

    def index = {
        redirect(action: "list", params: params)
    }

    def list = {
        params.max = Math.min(params.max ? params.int('max') : 10, 100)
        [appConfigInfoInstanceList: AppConfigInfo.list(params), appConfigInfoInstanceTotal: AppConfigInfo.count()]
    }

    def create = {
        def appConfigInfoInstance = new AppConfigInfo()
        appConfigInfoInstance.properties = params
        return [appConfigInfoInstance: appConfigInfoInstance]
    }

    def save = {
        def appConfigInfoInstance = new AppConfigInfo(params)
        if (appConfigInfoInstance.save(flush: true)) {
            flash.message = "${message(code: 'default.created.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), appConfigInfoInstance.id])}"
            redirect(action: "show", id: appConfigInfoInstance.id)
        }
        else {
            render(view: "create", model: [appConfigInfoInstance: appConfigInfoInstance])
        }
    }

    def show = {
//        def appConfigInfoInstance = AppConfigInfo.get(params.id)
		/**
		 * MODIFIED - Changed the fetch to retrieve data from the model via a composite key
		 */
		def appConfigInfoInstance = AppConfigInfo.get(new AppConfigInfo(params))
        if (!appConfigInfoInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), params.id])}"
            redirect(action: "list")
        }
        else {
            [appConfigInfoInstance: appConfigInfoInstance]
        }
    }

    def edit = {
//        def appConfigInfoInstance = AppConfigInfo.get(params.id)
		/**
		 * MODIFIED - Changed the fetch to retrieve data from the model via a composite key. We need to specify 
		 * the hidden fields
		 */
		def appConfigInfoInstance = AppConfigInfo.get(new AppConfigInfo([configName:params.id, propertyName:params.value]))
        if (!appConfigInfoInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), params.id])}"
            redirect(action: "list")
        }
        else {
            return [appConfigInfoInstance: appConfigInfoInstance]
        }
    }

    def update = {
        def appConfigInfoInstance = AppConfigInfo.get(params.id)
        if (appConfigInfoInstance) {
            if (params.version) {
                def version = params.version.toLong()
                if (appConfigInfoInstance.version > version) {
                    
                    appConfigInfoInstance.errors.rejectValue("version", "default.optimistic.locking.failure", [message(code: 'appConfigInfo.label', default: 'AppConfigInfo')] as Object[], "Another user has updated this AppConfigInfo while you were editing")
                    render(view: "edit", model: [appConfigInfoInstance: appConfigInfoInstance])
                    return
                }
            }
            appConfigInfoInstance.properties = params
            if (!appConfigInfoInstance.hasErrors() && appConfigInfoInstance.save(flush: true)) {
                flash.message = "${message(code: 'default.updated.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), appConfigInfoInstance.id])}"
                redirect(action: "show", id: appConfigInfoInstance.id)
            }
            else {
                render(view: "edit", model: [appConfigInfoInstance: appConfigInfoInstance])
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), params.id])}"
            redirect(action: "list")
        }
    }

    def delete = {
//        def appConfigInfoInstance = AppConfigInfo.get(params.id)
		/**
		 * MODIFIED - Changed the fetch to retrieve data from the model via a composite key. We need to specify 
		 * the hidden fields
		 */
		def appConfigInfoInstance = AppConfigInfo.get(new AppConfigInfo([configName:params.id, propertyName:params.value]))
        if (appConfigInfoInstance) {
            try {
                appConfigInfoInstance.delete(flush: true)
                flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), params.id])}"
                redirect(action: "list")
            }
            catch (org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), params.id])}"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'appConfigInfo.label', default: 'AppConfigInfo'), params.id])}"
            redirect(action: "list")
        }
    }
}
