package example
/**
 * example domain object that uses a database table with a composite key
 * 
 * @author codethought
 */
class AppConfigInfo implements Serializable {
	String configName
	String propertyName
	String propertyValue
	String description
	Date updated

	/*
	 * basic constraints to specify the field order. needed when
	 * views are generated for the controller
	 * 
	 */
    static constraints = {
		configName (blank:false)
		propertyName (blank:false)
		propertyValue (blank:false)
		description (maxSize:80)
		updated()
    }
	
	/*
	 * this mapping configures the columns to match up to the legacy 
	 * database table.
	 */
	static mapping = {
		table 'APPLICATION_CONFIG'
		// this line will disable the version number support required
		// for GORM optimistic locking.  comment out or remove
		// if you want to support locking (recommended, not required) 
		version false
		id composite:['configName','propertyName']
		
		//maps the columns to the properties in the domain
		columns {
			configName column:'CONFIG_NAME'
			propertyName column:'KEYNAME'
			propertyValue column:'VALUE'
			description column:'DESCRIPTION', type:'text'
			updated column:'LAST_UPDATED'
		}
	}
	
	//if you have separate columns for created and updated timestamps
	//you can skip this code and map the above columns accordingly
	//most of the time in my experience, schemas have only one column for this
	
	def beforeInsert = {
		updated = new Date()
	}
	
	def beforeUpdate = {
		updated = new Date()
	}
	
	def getPK() {
		["configName":configName, "propertyName":propertyName]
	}
	
}
